/* $Header: /fridge/cvs/xscorch/sutil/srand.h,v 1.5 2004/02/26 06:34:57 justins Exp $ */
/*

   xscorch - srand.h          Copyright(c) 2000 Justin David Smith
   justins(at)chaos2.org      http://chaos2.org/

   Scorched random numbers


   This program is free software; you can redistribute it and/or modify 
   it under the terms of the GNU General Public License as published by 
   the Free Software Foundation, version 2 of the License ONLY. 

   This program is distributed in the hope that it will be useful, 
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/
#ifndef __srand_h_included
#define __srand_h_included

#include <xscorch.h>


/* Random functions */
void     sys_randomize(void);
long     sys_rand(void);
double   sys_drand(void);
long     sys_lrand(long max);

#define  GAME_RAND_MAX  RAND_MAX
void     game_randomize(dword seed);
dword    game_rand(void);
dword    game_rand_peek(void);
double   game_drand(void);
dword    game_lrand(dword max);


#endif /* __srand_h_included */
